=====================
Aleph.im NULS2 Python
=====================

Python library to interact with the NULS2 blockchain.

Description
===========

Features:

* Sign data with a NULS2 private key.
* Verify signatures.

Note
====

This project has been set up using PyScaffold 3.2.1. For details and usage
information on PyScaffold see https://pyscaffold.org/.
